@@ -5,7 +5,7 @@ use warnings;
 package Data::Fake;
 # ABSTRACT: Declaratively generate fake structured data for testing
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Import::Into;
 
@@ -34,7 +34,7 @@ Data::Fake - Declaratively generate fake structured data for testing
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -283,6 +283,22 @@ L<https://github.com/dagolden/Data-Fake>
 
 David Golden <dagolden@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords David Golden Ricardo Signes
+
+=over 4
+
+=item *
+
+David Golden <xdg@xdg.me>
+
+=item *
+
+Ricardo Signes <rjbs@users.noreply.github.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2015 by David Golden.
