@@ -5,7 +5,7 @@ use warnings;
 package Data::Fake::Core;
 # ABSTRACT: General purpose generators
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Exporter 5.57 qw/import/;
 
@@ -235,18 +235,20 @@ sub fake_float {
 
 #pod =func fake_digits
 #pod
-#pod     $generator = fake_digits("###-####"); # "555-1234"
-#pod     $generator = fake_digits("\###");     # "#12"
+#pod     $generator = fake_digits('###-####'); # "555-1234"
+#pod     $generator = fake_digits('\###');     # "#12"
 #pod
 #pod Given a text pattern, returns a generator that replaces all occurrences of
 #pod the sharp character (C<#>) with a randomly selected digit.  To have a
-#pod literal sharp character, escape it with a backslash.
+#pod literal sharp character, escape it with a backslash (do it in a
+#pod single-quoted string to avoid having to double your backslash to get a
+#pod backslash in the string.).
 #pod
 #pod Use this for phone numbers, currencies, or whatever else needs random
 #pod digits:
 #pod
-#pod     fake_digits("###-##-####");     # US Social Security Number
-#pod     fake_digits("(###) ###-####");  # (800) 555-1212
+#pod     fake_digits('###-##-####');     # US Social Security Number
+#pod     fake_digits('(###) ###-####');  # (800) 555-1212
 #pod
 #pod =cut
 
@@ -354,7 +356,7 @@ Data::Fake::Core - General purpose generators
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -503,18 +505,20 @@ will produce a random floating point value in that range.
 
 =head2 fake_digits
 
-    $generator = fake_digits("###-####"); # "555-1234"
-    $generator = fake_digits("\###");     # "#12"
+    $generator = fake_digits('###-####'); # "555-1234"
+    $generator = fake_digits('\###');     # "#12"
 
 Given a text pattern, returns a generator that replaces all occurrences of
 the sharp character (C<#>) with a randomly selected digit.  To have a
-literal sharp character, escape it with a backslash.
+literal sharp character, escape it with a backslash (do it in a
+single-quoted string to avoid having to double your backslash to get a
+backslash in the string.).
 
 Use this for phone numbers, currencies, or whatever else needs random
 digits:
 
-    fake_digits("###-##-####");     # US Social Security Number
-    fake_digits("(###) ###-####");  # (800) 555-1212
+    fake_digits('###-##-####');     # US Social Security Number
+    fake_digits('(###) ###-####');  # (800) 555-1212
 
 =head2 fake_template
 
